Query

Trait Query 

pub trait Query {
    type Scheme;
    type Args;

    // Required method
    fn send<'async_trait>(
        __arg0: Self::Args,
    ) -> Pin<Box<dyn Future<Output = Result<Self::Scheme, ErrorType>> + Send + 'async_trait>>
       where Self: 'async_trait;
}
Defines a query, which takes one or more arguments.

Required Associated Types

type Scheme

Defines the scheme that the API shall return.

type Args

Defines which args will be passed into the API.

Required Methods

fn send<'async_trait>( __arg0: Self::Args, ) -> Pin<Box<dyn Future<Output = Result<Self::Scheme, ErrorType>> + Send + 'async_trait>>
where Self: 'async_trait,

Sends the query to the API.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors